@@ -1,5 +1,5 @@
 package Bot::Cobalt::IRC::Event;
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 ## Base class for IRC events.
 
@@ -7,9 +7,19 @@ use 5.10.1;
 use Bot::Cobalt::Common;
 use Moo;
 
-has 'context' => ( is => 'rw', isa => Str, required => 1 );
+has 'context' => ( 
+  required => 1,
+
+  is  => 'rw', 
+  isa => Str,
+);
+
+has 'src'     => (
+  required => 1, 
+
+  is  => 'rw', 
+  isa => Str, 
 
-has 'src'     => ( is => 'rw', isa => Str, required => 1, 
   trigger => sub {
     ## If 'src' changes, reset nick/user/host as-needed.
     my ($self, $value) = @_;
