@@ -1,5 +1,5 @@
 package Bot::Cobalt::IRC::Event::Quit;
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 use Moo;
 use strictures 1;
@@ -7,11 +7,21 @@ use Bot::Cobalt::Common qw/:types/;
 
 extends 'Bot::Cobalt::IRC::Event';
 
-has 'reason' => ( is => 'rw', isa => Str, lazy => 1, 
+has 'reason' => ( 
+  lazy => 1, 
+
+  is  => 'rw', 
+  isa => Str, 
+
   default => sub {''},
 );
 
-has 'common' => ( is => 'rw', isa => ArrayRef, lazy => 1,
+has 'common' => ( 
+  lazy => 1,
+
+  is  => 'rw', 
+  isa => ArrayRef,
+
   default => sub {[]},
 );
 
