@@ -1,5 +1,5 @@
 package Bot::Cobalt::IRC::Server;
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 ## A server context.
 
@@ -9,33 +9,72 @@ use 5.10.1;
 use Moo;
 use Bot::Cobalt::Common qw/:types/;
 
-has 'name' => ( is => 'rw', isa => Str, required => 1 );
+has 'name' => ( 
+  required => 1,
 
-has 'prefer_nick' => ( is => 'rw', isa => Str, required => 1 );
+  is  => 'rw', 
+  isa => Str, 
+);
+
+has 'prefer_nick' => (
+  required => 1, 
+
+  is  => 'rw', 
+  isa => Str, 
+);
+
+has 'irc' => (
+  is  => 'rw', 
+  isa => Object,
 
-has 'irc' => ( is => 'rw', isa => Object,
   predicate => 'has_irc',
   clearer   => 'clear_irc',
 );
 
-has 'connected' => ( is => 'rw', isa => Bool, lazy => 1,
-  default => sub { 0 },
+has 'connected' => (
+  lazy => 1,
+
+  is  => 'rw', 
+  isa => Bool, 
+
   clearer => 'clear_connected',
-);
 
-has 'connectedat' => ( is => 'rw', isa => Num, lazy => 1,
   default => sub { 0 },
 );
 
-has 'casemap' => ( is => 'rw', isa => Str, lazy => 1,
+has 'connectedat' => (
+  lazy => 1,
+
+  is  => 'rw', 
+  isa => Num, 
+
+  default => sub { 0 },
+);
+
+has 'casemap' => (
+  lazy => 1,
+
+  is  => 'rw', 
+  isa => Str, 
+
   default => sub { 'rfc1459' },
 ); 
 
-has 'maxmodes' => ( is => 'rw', isa => Int, lazy => 1,
+has 'maxmodes' => (
+  lazy => 1,
+
+  is => 'rw', 
+  isa => Int, 
+
   default => sub { 3 },
 );
 
-has 'maxtargets' => ( is => 'rw', isa => Int, lazy => 1,
+has 'maxtargets' => (
+  lazy => 1,
+  
+  is  => 'rw', 
+  isa => Int, 
+  
   default => sub { 4 },
 );
 
